@@ -91,7 +91,11 @@ def create_all_module_info(
     )
 
     return _get_all_module_info(
-        module_names, pkg_dependencies_data, module_segmenter, module_creator
+        module_names,
+        pkg_dependencies_data,
+        module_segmenter,
+        module_creator,
+        start_location,
     )
 
 
@@ -154,6 +158,7 @@ def _get_all_module_info(
     pkg_module_dep_info: Dict[str, Set[str]],
     module_segmenter: module_segmenter,
     module_creator: module_info_creator,
+    start_location: str,
 ) -> List[Union[RelativeModuleInfo, StdLibModuleInfo, PackagedModuleInfo]]:
     """Given a list of modules, compute all dependent module information using the given helper functions and information.
 
@@ -194,8 +199,8 @@ def _get_all_module_info(
     for relative_module in direct_relative_modules:
 
         l, p = _parse_levels(relative_module.module_name)
-        t = (Path(relative_module.absolute_fs_position).parent,)
-        new_relative_path = move_to(str(t[0]), l, p[:-1])
+        t = Path(start_location)
+        new_relative_path = move_to(str(t), l, p)
 
         (
             tmp_relative_module_dependencies,
@@ -245,7 +250,7 @@ def _create_module_info(
     module_name: str,
     start_location: FilePath,
     standard_library: Set[str],
-    packaged_module_locations_tags: Dict[str, FilePath],
+    packaged_module_locations_tags: Dict[str, Tuple[str, str, str, str]],
 ) -> ModuleInfo:
     """Given a module_name, create a ModuleInfo object based on the current environment expressed by the parameters.
 
@@ -270,16 +275,18 @@ def _create_module_info(
         return _create_std_library_module_info(module_name)
 
     elif module_name in packaged_module_locations_tags:
-        location, tag, namespace = packaged_module_locations_tags.get(module_name)
-        x = _create_packaged_module_info(
+        location, tag, namespace, record_location = packaged_module_locations_tags.get(
+            module_name
+        )
+        return _create_packaged_module_info(
             module_name,
             _get_module_abs_path(module_name, location)
             if not namespace
             else _get_module_abs_path(namespace, location),
             tag,
             namespace,
+            record_location,
         )
-        return x
 
     else:
         raise PackagingError(
@@ -369,7 +376,6 @@ def _recursive_find_relative_module_dependencies(
     ) = module_segmenter(direct_dependencies)
 
     # Update the module creator to point to the new base directory for relative imports
-
     module_creator = partial(module_creator, start_location=update_relative_path)
 
     # Sets we will add to for each type of module
@@ -384,6 +390,7 @@ def _recursive_find_relative_module_dependencies(
     # For the relative dependencies, Recursively find any other modules needed
     for relative_dependency in relative_dependencies_names:
         l, p = _parse_levels(relative_dependency)
+
         new_relative_path = move_to(update_relative_path, l, p)
 
         (
@@ -473,7 +480,11 @@ def _create_relative_module_info(
 
 
 def _create_packaged_module_info(
-    module_symbol: str, filepath: FilePath, tag: str, namespace: str
+    module_symbol: str,
+    filepath: FilePath,
+    tag: str,
+    namespace: str,
+    record_location: str,
 ) -> PackagedModuleInfo:
     """Create a PackagedModuleInfo object
 
@@ -498,6 +509,7 @@ def _create_packaged_module_info(
         is_dir=is_dir,
         tag=tag,
         namespace=namespace,
+        record_location=record_location,
     )
 
 
@@ -613,7 +625,7 @@ def _recursive_get_all_dependencies(
 
 def _get_packages_modules_location_tag_info(
     package: Distribution,
-) -> Dict[str, Tuple[str, str, str]]:
+) -> Dict[str, Tuple[str, str, str, str]]:
     """Get all the top level modules available from a given package
 
     Returns:
@@ -651,7 +663,12 @@ def _get_packages_modules_location_tag_info(
             # This is a namespace package (https://packaging.python.org/en/latest/guides/packaging-namespace-packages/)
             _namespace = _actual_top_level_modules.pop()
             return {
-                _converted_package_name: (base_directory_location, tags, _namespace)
+                _converted_package_name: (
+                    base_directory_location,
+                    tags,
+                    _namespace,
+                    record_location,
+                )
             }
 
     with open(toplevel_location) as fh:
@@ -659,7 +676,8 @@ def _get_packages_modules_location_tag_info(
         top_level_mod_names = fh.readlines()
 
     return {
-        x.strip(): (base_directory_location, tags, None) for x in top_level_mod_names
+        x.strip(): (base_directory_location, tags, None, record_location)
+        for x in top_level_mod_names
     }
 
 
@@ -874,6 +892,7 @@ def put_relative_modules_cache(
 
 
 def _parse_levels(t: str) -> Tuple[int, List[str]]:
+
     x = t.split(".")
 
     if not x[0] == "":
@@ -890,6 +909,7 @@ def _parse_levels(t: str) -> Tuple[int, List[str]]:
 
 
 def move_to(start: str, up_levels: int, down_dirs: List[str]) -> str:
+
     base = Path(start).parents[up_levels - 1] if up_levels > 0 else Path(start)
 
     for down in down_dirs:
